@@ -15,18 +15,15 @@ __helpstr__ = """Usage: nodevers remove <version> [options]
 import shutil
 import sys
 import getopt
-from . import cli
-from . import misc
-from . import use
-from . import version
+import nodevers.shared as shared
 
 def remove(ver):
     """
     Uninstalls the specified version.
     """
-    if ver == version.current_version():
-        use.link_to("system")
-    shutil.rmtree(misc.get_version_dir(ver))
+    if ver == shared.current_version():
+        shared.link_to("system")
+    shutil.rmtree(shared.get_version_dir(ver))
 
 def parse(args):
     """
@@ -34,7 +31,7 @@ def parse(args):
     based on them.
     """
     if len(args) == 0:
-        cli.help_func(__helpstr__)
+        shared.help_func(__helpstr__)
     else:
         try:
             optlist, arglist = getopt.getopt(args, "h", ["help"])
@@ -44,8 +41,8 @@ def parse(args):
             sys.exit(-1)
         for option, value in optlist:
             if option in ("-h", "--help"):
-                cli.help_func(__helpstr__)
-        if misc.version_exists(args[0]):
+                shared.help_func(__helpstr__)
+        if shared.version_exists(args[0]):
             remove(args[0])
         else:
-            sys.stdout.write("There is no such version installed.\n")
+            sys.stdout.write("Error: there is no such version installed\n")
