@@ -15,22 +15,8 @@ __helpstr__ = """Usage: nodevers use <version> [options]
 import os
 import sys
 import getopt
-from . import cli
-from . import misc
+import nodevers.shared as shared
 
-def link_to(ver):
-    """
-    Create a symlink to the specified Node's
-    bin dir in nodevers prefix.
-    """
-    if ver == "system":
-        os.unlink(misc.get_bin_dir())
-    else:
-        if os.path.lexists(misc.get_bin_dir()):
-            os.unlink(misc.get_bin_dir())
-        version_bin_dir = os.path.join(misc.get_version_dir(ver),
-                "bin")
-        os.symlink(version_bin_dir, misc.get_bin_dir())
 
 def parse(args):
     """
@@ -38,7 +24,7 @@ def parse(args):
     based on them.
     """
     if len(args) == 0 or args[0] in ("-h", "--help"):
-        cli.help_func(__helpstr__)
+        shared.help_func(__helpstr__)
     else:
         try:
             optlist, arglist = getopt.getopt(args[1:], "h", ["help"])
@@ -48,8 +34,9 @@ def parse(args):
             sys.exit(-1)
         for option, value in optlist:
             if option in ("-h", "--help"):
-                cli.help_func(__helpstr__)
-        if misc.version_exists(args[0]) or args[0] == "system":
-            link_to(args[0])
-        else:
-            sys.stdout.write("There is no such version installed.\n")
+                shared.help_func(__helpstr__)
+        try:
+            shared.link_to(args[0])
+        except shared.NoSuchVersionError:
+            err = sys.exc_info()[1]
+            sys.stdout.write("Error: %s\n" % str(err))
