@@ -15,14 +15,13 @@ __helpstr__ = """Usage: nodevers versions [options]
 import os
 import sys
 import getopt
-from . import misc
-from . import cli
+import nodevers.shared as shared
 
 def get_versions_list():
     """
     Return a list of all the installed Node versions.
     """
-    versions_dir = misc.get_versions_dir()
+    versions_dir = shared.get_versions_dir()
     # os.path.isdir() will fail unless we do this.
     os.chdir(versions_dir)
     versions = [ver for ver in os.listdir(versions_dir) if os.path.isdir(ver)]
@@ -41,8 +40,8 @@ def parse(args):
             optlist, arglist = getopt.getopt(args, "h", ["help"])
         except getopt.error:
             err = sys.exc_info()[1]
-            sys.stderr.write("Error: %s.\n" % str(err))
+            sys.stderr.write("Error: %s\n" % str(err))
             sys.exit(-1)
         for option, value in optlist:
             if option in ("-h", "--help"):
-                cli.help_func(__helpstr__)
+                shared.help_func(__helpstr__)
